@@ -10,11 +10,10 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
-use Devel::Cover::DB 0.28;
+use Devel::Cover::DB 0.29;
 
-use Cwd ();
 use Template 2.00;
 
 my $Template;
@@ -72,11 +71,10 @@ sub print_summary
         vals        => \%vals,
     };
 
-    my $html = "$db->{db}/$db->{db}.html";
+    my $html = "$options->{outputdir}/coverage.html";
     $Template->process("summary", $vars, $html) or die $Template->error();
 
-    my $cwd = Cwd::cwd();
-    print "HTML output sent to $cwd/$html\n";
+    print "HTML output sent to $html\n";
 }
 
 sub print_file
@@ -155,7 +153,7 @@ sub print_file
         lines       => \@lines,
     };
 
-    my $html = "$db->{db}/$Filenames{$file}.html";
+    my $html = "$options->{outputdir}/$Filenames{$file}.html";
     $Template->process("file", $vars, $html) or die $Template->error();
 }
 
@@ -193,7 +191,7 @@ sub print_branches
         branches => \@branches,
     };
 
-    my $html = "$db->{db}/$Filenames{$file}--branch.html";
+    my $html = "$options->{outputdir}/$Filenames{$file}--branch.html";
     $Template->process("branches", $vars, $html) or die $Template->error();
 }
 
@@ -242,7 +240,7 @@ sub print_conditions
     # use Data::Dumper;
     # print Dumper $vars;
 
-    my $html = "$db->{db}/$Filenames{$file}--condition.html";
+    my $html = "$options->{outputdir}/$Filenames{$file}--condition.html";
     $Template->process("conditions", $vars, $html)
         or die $Template->error();
 }
@@ -280,7 +278,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
 use base "Template::Provider";
 
@@ -316,7 +314,7 @@ $Templates{html} = <<'EOT';
 
 <!--
 
-This file was generated by Devel::Cover Version 0.28
+This file was generated by Devel::Cover Version 0.29
 
 Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
 
@@ -535,7 +533,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.28 - 1st December 2003
+Version 0.29 - 19th December 2003
 
 =head1 LICENCE
 
