@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.28;
-use Devel::Cover::Truth_Table 0.28;
+use Devel::Cover::DB 0.29;
+use Devel::Cover::Truth_Table 0.29;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -146,7 +146,6 @@ sub merge_lineops {
 
 #===============================================================================
 my %Filenames;
-my %File_exists;
 my @class = qw'c0 c1 c2 c3';
 
 #-------------------------------------------------------------------------------
@@ -256,7 +255,7 @@ sub print_html_header {
 
     print $fh <<"END_HTML";
 <!--
-This file was generated by Devel::Cover Version 0.28
+This file was generated by Devel::Cover Version 0.29
 Devel::Cover is copyright 2001-2003, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
@@ -675,10 +674,8 @@ sub get_options
 sub report {
     my (undef, $db, $opt) = @_;
 
-    my @files = @{$opt->{file}};
-
-    %Filenames   = map {$_ => do {(my $f = $_) =~ s/\W/-/g; $f}} @files;
-    %File_exists = map {$_ => -e} @files;
+    my @files  = @{$opt->{file}};
+    %Filenames = map {$_ => do {(my $f = $_) =~ s/\W/-/g; $f}} @files;
 
     print_stylesheet($db, $opt);
     print_summary_report($db, $opt);
@@ -709,38 +706,37 @@ statistics
 
 =head1 DESCRIPTION
 
-This module provides a HTML reporting mechanism for coverage data. It
-is designed to be called from the C<cover> program.
+This module provides a HTML reporting mechanism for coverage data. It is
+designed to be called from the C<cover> program.
 
-Based on an original by Paul Johnson, the output was greatly improved by
-Michael Carman (mjcarman@mchsi.com).
+Based on an original by Paul Johnson, the output was greatly improved by Michael
+Carman (mjcarman@mchsi.com).
 
 =head1 OPTIONS
 
-Options are specified by adding the appropraite flags to the C<cover>
-program.  This report format supports the following:
+Options are specified by adding the appropraite flags to the C<cover> program.
+This report format supports the following:
 
 =over 4
 
 =item pod
 
-Includes POD (and blank lines) in the file report. This is on by default.
+Includes POD (and blank lines) in the file report. This is on by default.  It
+may be turned off with -nopod.
 
 =item data
 
-Includes text after the C<__DATA__> or C<__END__> tokens in the file 
-report. By default, this text is trimmed.
+Includes text after the C<__DATA__> or C<__END__> tokens in the file report. By
+default, this text is trimmed.
 
-Note: If your POD is after an C<__END__>, you have to specify 'data' to 
-include it, not 'pod'. The 'pod' option only applies to POD before the 
-C<__END__>.
+Note: If your POD is after an C<__END__>, you have to specify 'data' to include
+it, not 'pod'. The 'pod' option only applies to POD before the C<__END__>.
 
 =item unified
 
-Generates a "unified" report for each file. The detailed data that 
-normally appears in the auxilliary reports (branch, condition, etc.) is 
-placed in the file report, and the auxilliarry reports are not 
-generated.
+Generates a "unified" report for each file. The detailed data that normally
+appears in the auxilliary reports (branch, condition, etc.) is placed in the
+file report, and the auxilliarry reports are not generated.
 
 =back
 
@@ -750,7 +746,7 @@ Devel::Cover
 
 =head1 VERSION
 
-Version 0.28 - 1st December 2003
+Version 0.29 - 19th December 2003
 
 =head1 LICENCE
 
