@@ -2,12 +2,11 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
-use Devel::Cover::DB 0.28;
-use Devel::Cover::Truth_Table 0.28;
+use Devel::Cover::DB 0.29;
+use Devel::Cover::Truth_Table 0.29;
 
-use Cwd();
 use Template 2.00;
 use CGI;
 
@@ -102,11 +101,10 @@ sub print_summary {
 		vals        => \%vals,
 	};
 
-	my $html = "$db->{db}/$db->{db}.html";
+	my $html = "$options->{outputdir}/coverage.html";
 	$Template->process("summary", $vars, $html) or die $Template->error();
 
-	my $cwd = Cwd::cwd();
-	print "HTML output sent to $cwd/$html\n";
+	print "HTML output sent to $html\n";
 }
 
 
@@ -228,7 +226,7 @@ sub print_file {
 		platform    => $^O,                                 # should come from db
 	};
 
-	my $html = "$db->{db}/$Filenames{$file}.html";
+	my $html = "$options->{outputdir}/$Filenames{$file}.html";
 	$Template->process("file", $vars, $html) or die $Template->error();
 }
 
@@ -273,7 +271,7 @@ sub print_branches {
 		platform    => $^O,                                 # should come from db
 	};
 
-	my $html = "$db->{db}/$Filenames{$file}--branch.html";
+	my $html = "$options->{outputdir}/$Filenames{$file}--branch.html";
 	$Template->process("branches", $vars, $html) or die $Template->error();
 }
 
@@ -388,7 +386,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
 use base "Template::Provider";
 
@@ -406,7 +404,7 @@ sub fetch {
 $Templates{html} = <<'EOT';
 <!--
 
-This file was generated by Devel::Cover Version 0.28
+This file was generated by Devel::Cover Version 0.29
 
 Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
 
@@ -736,7 +734,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.28 - 1st December 2003
+Version 0.29 - 19th December 2003
 
 =head1 LICENCE
 
